/**
 * OW2 Specifications
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JMSSessionStats.java 1506 2007-06-30 15:34:09Z sauthieg $
 * --------------------------------------------------------------------------
 */

package javax.management.j2ee.statistics;
 
/**
 * Specifies the statistics provided by a JMS session.
 * @author Guillaume Sauthier
 */
public interface JMSSessionStats extends Stats {

    /**
     * @return Returns an array of JMSProducerStats that provide statistics
     *         about the message producers associated with the referencing
     *         JMS session statistics.
     */
    JMSProducerStats[] getProducers();
    
    /**
     * @return Returns an array of JMSConsumerStats that provide statistics
     *         about the message consumers associated with the referencing
     *         JMS session statistics.
     */
    JMSConsumerStats[] getConsumers();
    
    /**
     * @return Number of messages exchanged.
     */
    CountStatistic getMessageCount();
    
    /**
     * @return Number of pending messages.
     */
    CountStatistic getPendingMessageCount();
    
    /**
     * @return Number of expired messages.
     */
    CountStatistic getExpiredMessageCount();
    
    /**
     * @return Time spent by a message before being delivered.
     */
    TimeStatistic getMessageWaitTime();
    
    /**
     * @return Number of durable subscriptions.
     */
    CountStatistic getDurableSubscriptionCount();
}
